package cz.zweistein.df.soundsense.config;

import java.util.List;
import java.util.Random;

public class Sound {
	
	private List<SoundFile> soundFiles;
	private int soundFilesWeightsSum;
	
	private String logPattern;
	
	private String parentFile;
	
	// loop repeats indefinitely, only music can loop
	private Loop loop;
	// there can be only one sound played on channel.
	private String channel;
	
	// concurency is cap on how many sounds can be played concurenctly to this one.
	// if more sounds are playing than this number and this sound is triggered, it would be ignored.
	private Integer concurency; 
	// is set, engine echoes log line 
	private boolean speech;
	
	private boolean haltOnMatch;
	
	public Sound(String parentFile, List<SoundFile> soundFiles, String logPattern, Loop loop, String channel, Integer concurency, boolean speech, boolean haltOnMatch) {
		this.parentFile = parentFile;
		this.soundFiles = soundFiles;
		this.logPattern = logPattern;
		this.loop = loop;
		this.channel = channel;
		this.concurency = concurency;
		this.speech = speech;
		this.haltOnMatch = haltOnMatch;
		
		this.soundFilesWeightsSum = 0;
		for (SoundFile soundFile: this.soundFiles) {
			this.soundFilesWeightsSum += soundFile.getWeight();
		}
		
	}

	public boolean getSpeech() {
		return this.speech;
	}

	public Integer getConcurency() {
		return this.concurency;
	}

	public String getLogPattern() {
		return this.logPattern;
	}
	
	public Loop getLoop() {
		return this.loop;
	}
	
	public boolean hasNoSoundFiles() {
		return this.soundFiles.isEmpty();
	}

	public SoundFile getSoundFile() {
		
		if (this.soundFiles.size() > 0) {
			int weightedRandom = new Random().nextInt(this.soundFilesWeightsSum);
			for (SoundFile soundFile: this.soundFiles) {
				if (soundFile.getWeight() > weightedRandom) {
					return soundFile;
				}
				weightedRandom -= soundFile.getWeight();
			}
			
		}
	
		return null;
		
	}

	public String getParentFile() {
		return this.parentFile;
	}

	public String getChannel() {
		return channel;
	}

	public boolean getHaltOnMatch() {
		return this.haltOnMatch;
	}

}
